from typing import Optional, List
from datetime import datetime

from runai import models
from runai.api.runai_api_service import RunaiAPIService, deprecated_message


class NodePoolsApi(RunaiAPIService):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        self._api_client = api_client

    def create_node_pool(
        self,
        cluster_id: str,
        node_pool_create_request: Optional[models.NodePoolCreateRequest] = None,
    ):
        r"""


        ### Description
        Create a Node Pool.

        ### Parameters:
        ```python
        cluster_id: str
        node_pool_create_request: NodePoolCreateRequest
        ```
        cluster_id: Unique identifier of the cluster
        node_pool_create_request: See model NodePoolCreateRequest for more information.

        ### Example:
        ```python
        NodePoolsApi(
            cluster_id='cluster_id_example',
                        node_pool_create_request=runai.NodePoolCreateRequest()
        )
        ```
        """

        # Body params:
        body_params = node_pool_create_request

        resource_path = f"/v1/k8s/clusters/{cluster_id}/node_pools".replace("_", "-")
        method = "POST"
        return self._api_client.call_api(
            resource_path=resource_path,
            method=method,
            body=body_params,
        )

    def delete_node_pool(
        self,
        cluster_id: str,
        id: int,
    ):
        r"""


        ### Description
        Delete a Node Pool by id.§

        ### Parameters:
        ```python
        cluster_id: str
        id: int
        ```
        cluster_id: Unique identifier of the cluster
        id: The unique id identifying the Node Pool.

        ### Example:
        ```python
        NodePoolsApi(
            cluster_id='cluster_id_example',
                        id=56
        )
        ```
        """

        resource_path = f"/v1/k8s/clusters/{cluster_id}/node_pools/{id}".replace(
            "_", "-"
        )
        method = "DELETE"
        return self._api_client.call_api(
            resource_path=resource_path,
            method=method,
        )

    def get_node_pools(
        self,
        cluster_id: str,
    ):
        r"""


        ### Description
        Get the cluster&#39;s Node Pools.

        ### Parameters:
        ```python
        cluster_id: str
        ```
        cluster_id: Unique identifier of the cluster

        ### Example:
        ```python
        NodePoolsApi(
            cluster_id='cluster_id_example'
        )
        ```
        """

        resource_path = f"/v1/k8s/clusters/{cluster_id}/node_pools".replace("_", "-")
        method = "GET"
        return self._api_client.call_api(
            resource_path=resource_path,
            method=method,
        )

    def get_nodepool_metrics(
        self,
        cluster_uuid: str,
        nodepool_name: str,
        start: datetime,
        end: datetime,
        metric_type: List[models.MetricsType],
        number_of_samples: Optional[int] = None,
    ):
        r"""


        ### Description
        Get the node pool metrics data. [Experimental]

        ### Parameters:
        ```python
        cluster_uuid: str
        nodepool_name: str
        start: Optional[datetime]
        end: Optional[datetime]
        metric_type: Optional[models.List[MetricsType]]
        number_of_samples: Optional[int]
        ```
        cluster_uuid: The Universally Unique Identifier (UUID) of the cluster.
        nodepool_name: The unique nodepool name.
        start: Start date of time range to fetch data in ISO 8601 timestamp format.
        end: End date of time range to fetch data in ISO 8601 timestamp format.
        metric_type: specifies what data to request
        number_of_samples: The number of samples to take in the specified time range. - Default: 20

        ### Example:
        ```python
        NodePoolsApi(
            cluster_uuid='9f55255e-11ed-47c7-acef-fc4054768dbc',
                        nodepool_name='default',
                        start='2023-06-06T12:09:18.211Z',
                        end='2023-06-07T12:09:18.211Z',
                        metric_type=[runai.MetricsType()],
                        number_of_samples=20
        )
        ```
        """

        # Query params:
        query_params = [
            ("start", start),
            ("end", end),
            ("numberOfSamples", number_of_samples),
            ("metricType", metric_type),
        ]
        resource_path = f"/api/v1/clusters/{cluster_uuid}/nodepools/{nodepool_name}/metrics".replace(
            "_", "-"
        )
        method = "GET"
        return self._api_client.call_api(
            resource_path=resource_path, method=method, query_params=query_params
        )

    def update_node_pool(
        self,
        cluster_id: str,
        id: int,
        update_node_pool_request: models.UpdateNodePoolRequest,
    ):
        r"""


        ### Description
        Update a Node Pool.

        ### Parameters:
        ```python
        cluster_id: str
        id: int
        update_node_pool_request: UpdateNodePoolRequest
        ```
        cluster_id: Unique identifier of the cluster
        id: The unique id identifying the Node Pool.
        update_node_pool_request: See model UpdateNodePoolRequest for more information.

        ### Example:
        ```python
        NodePoolsApi(
            cluster_id='cluster_id_example',
                        id=56,
                        update_node_pool_request=runai.UpdateNodePoolRequest()
        )
        ```
        """

        # Body params:
        body_params = update_node_pool_request

        resource_path = f"/v1/k8s/clusters/{cluster_id}/node_pools/{id}".replace(
            "_", "-"
        )
        method = "PUT"
        return self._api_client.call_api(
            resource_path=resource_path,
            method=method,
            body=body_params,
        )

    def update_node_pool_labels(
        self,
        cluster_id: str,
        id: int,
        node_pool_labels_request: models.NodePoolLabelsRequest,
    ):
        r"""


        ### Description
        Update labels of a Node Pool.

        ### Parameters:
        ```python
        cluster_id: str
        id: int
        node_pool_labels_request: NodePoolLabelsRequest
        ```
        cluster_id: Unique identifier of the cluster
        id: The unique id identifying the Node Pool.
        node_pool_labels_request: See model NodePoolLabelsRequest for more information.

        ### Example:
        ```python
        NodePoolsApi(
            cluster_id='cluster_id_example',
                        id=56,
                        node_pool_labels_request=runai.NodePoolLabelsRequest()
        )
        ```
        """

        # Body params:
        body_params = node_pool_labels_request

        resource_path = f"/v1/k8s/clusters/{cluster_id}/node_pools/{id}/labels".replace(
            "_", "-"
        )
        method = "PUT"
        return self._api_client.call_api(
            resource_path=resource_path,
            method=method,
            body=body_params,
        )
