from typing import Optional, List
from datetime import datetime

from runai import models
from runai.api.runai_api_service import RunaiAPIService, deprecated_message


class TokensApi(RunaiAPIService):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        self._api_client = api_client

    @deprecated_message()
    def app_token(
        self,
        app_token_request: Optional[models.AppTokenRequest] = None,
    ):
        r"""
        ## Deprecated endpoint, consider alternative method

        ### Description
        get application token

        ### Parameters:
        ```python
        app_token_request: AppTokenRequest
        ```
        app_token_request: See model AppTokenRequest for more information.

        ### Example:
        ```python
        TokensApi(
            app_token_request=runai.AppTokenRequest()
        )
        ```
        """

        # Body params:
        body_params = app_token_request

        resource_path = f"/v1/k8s/auth/oauth/apptoken".replace("_", "-")
        method = "POST"
        return self._api_client.call_api(
            resource_path=resource_path,
            method=method,
            body=body_params,
        )

    @deprecated_message()
    def exchange_code_for_token(
        self,
        redirect_uri: str,
        code: str,
    ):
        r"""
        ## Deprecated endpoint, consider alternative method

        ### Description
        exchange code for token

        ### Parameters:
        ```python
        redirect_uri: Optional[str]
        code: Optional[str]
        ```
        redirect_uri: The redirect uri to redirect to after the authorization server completes the authorization flow
        code: The exchange code retrieved from the idp server

        ### Example:
        ```python
        TokensApi(
            redirect_uri='redirect_uri_example',
                        code='code_example'
        )
        ```
        """

        # Query params:
        query_params = [
            ("redirectUri", redirect_uri),
            ("code", code),
        ]
        resource_path = f"/v1/k8s/auth/token/exchange".replace("_", "-")
        method = "GET"
        return self._api_client.call_api(
            resource_path=resource_path, method=method, query_params=query_params
        )

    def grant_token(
        self,
        user_agent: Optional[str] = None,
        token_request: Optional[models.TokenRequest] = None,
    ):
        r"""


        ### Description
        Create an application token.

        ### Parameters:
        ```python
        user_agent: str
        token_request: TokenRequest
        ```
        user_agent: See model str for more information.
        token_request: See model TokenRequest for more information.

        ### Example:
        ```python
        TokensApi(
            user_agent='user_agent_example',
                        token_request=runai.TokenRequest()
        )
        ```
        """

        # Body params:
        body_params = token_request

        resource_path = f"/api/v1/token".replace("_", "-")
        method = "POST"
        return self._api_client.call_api(
            resource_path=resource_path,
            method=method,
            body=body_params,
        )

    @deprecated_message()
    def refresh_token(
        self,
        refresh_token: str,
    ):
        r"""
        ## Deprecated endpoint, consider alternative method

        ### Description
        refresh token

        ### Parameters:
        ```python
        refresh_token: Optional[str]
        ```
        refresh_token: The refresh token retrieved from the idp server

        ### Example:
        ```python
        TokensApi(
            refresh_token='refresh_token_example'
        )
        ```
        """

        # Query params:
        query_params = [
            ("refreshToken", refresh_token),
        ]
        resource_path = f"/v1/k8s/auth/oauth/tokens/refresh".replace("_", "-")
        method = "POST"
        return self._api_client.call_api(
            resource_path=resource_path, method=method, query_params=query_params
        )
