# coding: utf-8

"""
    Runai API

    # Introduction  The Run:AI Control-Plane API reference is a guide that provides an easy-to-use programming interface for adding various tasks to your application, including workload submission, resource management, and administrative operations.  Run:ai APIs are accessed using *bearer tokens*. To obtain a token, you need to create an **Application** through the Run:ai user interface. To create an application, in your UI, go to `Settings & Tools`, `Application` and create a new Application.  After you have created a new application, you will need to assign it access rules. To assign access rules to the application, see [Create access rules](https://docs.run.ai/latest/admin/runai-setup/access-control/rbac/?h=create+delete+app#create-or-delete-rules). Make sure you assign the correct rules to your application. Use the [Roles](https://docs.run.ai/latest/admin/runai-setup/access-control/rbac/?h=create+delete+app#roles) to assign the correct access rules.  To get your access token, follow the instructions in [Request a token](https://docs.run.ai/latest/developer/rest-auth/#request-an-api-token). 

    The version of the OpenAPI document: 2.18
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from runai.models.pvc_access_modes import PvcAccessModes
from typing import Optional, Set
from typing_extensions import Self


class ClaimInfo(BaseModel):
    """
    Pydantic class model representing Claim information for the newly created PVC. The information should not be provided when attempting to use existing PVC..

    Parameters:
        ```python
        size: Optional[str]
        storage_class: Optional[str]
        access_modes: Optional[PvcAccessModes]
        volume_mode: Optional[str]
        ```
        size: Requested size for the PVC. Mandatory when &#x60;existingPvc&#x60; is &#x60;false&#x60; (mandatory)
        storage_class: Storage class name to associate with the PVC. This parameter may be omitted if there is a single storage class in the system, or you are using the default storage class. For more information, see [Storage class](https://kubernetes.io/docs/concepts/storage/storage-classes).
        access_modes: See model PvcAccessModes for more information.
        volume_mode: The volume mode required by the claim. Choose Filesystem (default) or Block.
    Example:
        ```python
        ClaimInfo(
            size='1G',
                        storage_class='my-storage-class',
                        access_modes=runai.models.pvc_access_modes.PvcAccessModes(
                    read_write_once = True,
                    read_only_many = True,
                    read_write_many = True, ),
                        volume_mode='Filesystem'
        )
        ```
    """  # noqa: E501

    size: Optional[Annotated[str, Field(strict=True)]] = Field(
        default=None,
        description="Requested size for the PVC. Mandatory when `existingPvc` is `false` (mandatory)",
    )
    storage_class: Optional[Annotated[str, Field(min_length=1, strict=True)]] = Field(
        default=None,
        description="Storage class name to associate with the PVC. This parameter may be omitted if there is a single storage class in the system, or you are using the default storage class. For more information, see [Storage class](https://kubernetes.io/docs/concepts/storage/storage-classes).",
        alias="storageClass",
    )
    access_modes: Optional[PvcAccessModes] = Field(default=None, alias="accessModes")
    volume_mode: Optional[StrictStr] = Field(
        default=None,
        description="The volume mode required by the claim. Choose Filesystem (default) or Block.",
        alias="volumeMode",
    )
    __properties: ClassVar[List[str]] = [
        "size",
        "storageClass",
        "accessModes",
        "volumeMode",
    ]

    @field_validator("size")
    def size_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if value is None:
            return value

        if not re.match(r"^([+-]?[0-9.]+)([eEinumkKMGTP]*[-+]?[0-9]*)$", value):
            raise ValueError(
                r"must validate the regular expression /^([+-]?[0-9.]+)([eEinumkKMGTP]*[-+]?[0-9]*)$/"
            )
        return value

    @field_validator("volume_mode")
    def volume_mode_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(["Filesystem", "Block"]):
            raise ValueError("must be one of enum values ('Filesystem', 'Block')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ClaimInfo from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of access_modes
        if self.access_modes:
            _dict["accessModes"] = self.access_modes.to_dict()
        # set to None if size (nullable) is None
        # and model_fields_set contains the field
        if self.size is None and "size" in self.model_fields_set:
            _dict["size"] = None

        # set to None if storage_class (nullable) is None
        # and model_fields_set contains the field
        if self.storage_class is None and "storage_class" in self.model_fields_set:
            _dict["storageClass"] = None

        # set to None if access_modes (nullable) is None
        # and model_fields_set contains the field
        if self.access_modes is None and "access_modes" in self.model_fields_set:
            _dict["accessModes"] = None

        # set to None if volume_mode (nullable) is None
        # and model_fields_set contains the field
        if self.volume_mode is None and "volume_mode" in self.model_fields_set:
            _dict["volumeMode"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ClaimInfo from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "size": obj.get("size"),
                "storageClass": obj.get("storageClass"),
                "accessModes": (
                    PvcAccessModes.from_dict(obj["accessModes"])
                    if obj.get("accessModes") is not None
                    else None
                ),
                "volumeMode": obj.get("volumeMode"),
            }
        )
        return _obj
